@@ -27,6 +27,8 @@ class BoardListView < KDE::ListView
   POPUP_OPEN_WITH_WEB_BROWSER = 0
   POPUP_COPY_URL = 1
   POPUP_COPY_TITLE_AND_URL = 2
+  POPUP_ADD_TO_FAVORITE = 3
+  POPUP_DELETE_FROM_FAVORITE = 4
 
   COLUMN_TITLE = 0
   COLUMN_URL = 1
@@ -74,8 +76,11 @@ class BoardListView < KDE::ListView
         board_name = Regexp.last_match[2]
 
         next unless Util.board_url?(board_url)
+        board_id = Util.board_url_to_board_id(board_url)
+
         board = Board.new(board_url, board_name)
-        BoardManager.instance.register(board_url, board_name)
+        BoardManager.instance.register_name(board_url, board_name)
+        BoardManager.instance.register_url("2ch", board_id, board_url)
         current_group.push(board) if current_group
       end
     }
@@ -92,8 +97,13 @@ class BoardListView < KDE::ListView
       }
     }
 
-    BoardManager.instance.register("http://jbbs.livedoor.jp/computer/18420/", "Kita板")
+    kitabbs_url = "http://jbbs.livedoor.jp/computer/18420/"
+    BoardManager.instance.register_name(kitabbs_url, "Kita板")
+    BoardManager.instance.register_url("jbbs.livedoor.jp", "computer_18420", kitabbs_url)
     KDE::ListViewItem.new(self, "Kita板", "http://jbbs.livedoor.jp/computer/18420/")
+
+    @favorite_item = KDE::ListViewItem.new(self, "お気に入り")
+    load_favorites
   end
 
   def show_board(item)
@@ -115,6 +125,11 @@ class BoardListView < KDE::ListView
     popup.insertItem("ウェブブラウザで開く", POPUP_OPEN_WITH_WEB_BROWSER)
     popup.insertItem("Copy URL", POPUP_COPY_URL)
     popup.insertItem("Copy title and URL", POPUP_COPY_TITLE_AND_URL)
+    if item.parent == @favorite_item then
+      popup.insertItem("お気に入りから削除", POPUP_DELETE_FROM_FAVORITE)
+    else
+      popup.insertItem("お気に入りに追加", POPUP_ADD_TO_FAVORITE)
+    end
 
     clipboard = Qt::Application.clipboard
     case popup.exec(pos)
@@ -127,6 +142,37 @@ class BoardListView < KDE::ListView
       cliptext = board_title + "\n" + board_url
       clipboard.setText(cliptext, Qt::Clipboard::Clipboard)
       clipboard.setText(cliptext, Qt::Clipboard::Selection)
+    when POPUP_ADD_TO_FAVORITE
+      add_to_favorite(board_url)
+    when POPUP_DELETE_FROM_FAVORITE
+      delete_from_favorite(item, board_url)
     end
   end
+
+  def add_to_favorite(board_url)
+    board_type = Util.board_url_to_board_type_name(board_url)
+    board_id = Util.board_url_to_board_id(board_url)
+    registered = FavoriteBoards.instance.register(board_type, board_id)
+
+    if registered then
+      board_name = BoardManager.instance.get_name(board_url)
+      KDE::ListViewItem.new(@favorite_item, board_name, board_url)
+    end
+  end
+
+  def delete_from_favorite(item, board_url)
+    board_type = Util.board_url_to_board_type_name(board_url)
+    board_id = Util.board_url_to_board_id(board_url)
+    FavoriteBoards.instance.delete(board_type, board_id)
+
+    @favorite_item.takeItem(item)
+  end
+
+  def load_favorites
+    FavoriteBoards.instance.each {|type, id|
+      board_url = BoardManager.instance.get_url(type, id)
+      board_name = BoardManager.instance.get_name(board_url)
+      KDE::ListViewItem.new(@favorite_item, board_name, board_url)
+    }
+  end
 end
