@@ -50,6 +50,17 @@ class Config
     @config.sync
   end
 
+  def auto_login
+    @config.setGroup("Account")
+    @config.readBoolEntry("AutoLogin")
+  end
+
+  def auto_login=(flag)
+    @config.setGroup("Account")
+    @config.writeEntry("AutoLogin", flag)
+    @config.sync
+  end
+
   def default_name
     @config.setGroup("Write")
     @config.readEntry("DefaultName")
