@@ -55,7 +55,11 @@ class DatInfo
     begin
       str = Downloader::load_dat(@dat_url)
     rescue
-      str = Downloader::download_dat(@dat_url)
+      begin
+        str = Downloader::download_dat(@dat_url)
+      rescue Net::ProtoRetriableError
+        str = Downloader::download_maru(@dat_url)
+      end
     end
 
     parse(str)
@@ -136,4 +140,11 @@ class DatInfo
 end
 
 class DatManager
+  def self.delete_dat(dat_url)
+    dat_path = Util.dat_url_to_dat_path(dat_url)
+    index_path = Util.dat_url_to_index_path(dat_url)
+
+    File::delete(dat_path)
+    File::delete(index_path)
+  end
 end
