@@ -46,6 +46,7 @@ require 'config.rb'
 require 'account.rb'
 require 'htmlpart.rb'
 require 'boardtabwidget.rb'
+require 'favoriteboards.rb'
 
 class ViewMediator
   def ViewMediator.thread_tab_widget=(tab_widget)
@@ -86,6 +87,9 @@ KDE::CmdLineArgs.init(ARGV, about)
 $app = KDE::UniqueApplication.new
 
 $main_window = MainWindow.new(0)
+pixmap = Qt::Pixmap.new
+pixmap.load("kita.png")
+$main_window.setIcon(pixmap)
 $main_window.resize(800, 600)
 $main_window.show
 
