@@ -42,6 +42,7 @@ class PreferenceDialog < KDE::DialogBase
     config = Config.instance
     @account_page.id_line.text = config.user_id
     @account_page.password_line.text = config.password
+    @account_page.autologin_check.setChecked(config.auto_login)
     @write_page.default_name_line.text = config.default_name
     @write_page.default_mail_line.text = config.default_mail
     @write_page.kotehan_edit.text = config.kotehan.join("\n")
@@ -50,6 +51,7 @@ class PreferenceDialog < KDE::DialogBase
   def save_config
     id = @account_page.id_line.text
     password = @account_page.password_line.text
+    auto_login = @account_page.autologin_check.checked
     default_name = @write_page.default_name_line.text
     default_mail = @write_page.default_mail_line.text
     kotehan = @write_page.kotehan_edit.text.split("\n").grep(/^.+$/)
@@ -57,6 +59,7 @@ class PreferenceDialog < KDE::DialogBase
     config = Config.instance
     config.user_id = id
     config.password = password
+    config.auto_login = auto_login
     config.default_name = default_name
     config.default_mail = default_mail
     config.kotehan = kotehan
