@@ -22,6 +22,7 @@
 class ThreadListView < Qt::Widget
   slots 'show_thread(QListViewItem*)'
   slots 'search()'
+  slots 'filter(bool)'
   slots 'context_menu(QListViewItem*,const QPoint&,int)'
   slots 'remove_self()'
 
@@ -33,9 +34,15 @@ class ThreadListView < Qt::Widget
   COLUMN_TITLE = 3
   COLUMN_RESNUM = 4
   COLUMN_READNUM = 5
-  COLUMN_OPENTIME = 6
-  COLUMN_SPEED = 7
-  COLUMN_URL = 8
+  COLUMN_UNREADNUM = 6
+  COLUMN_OPENTIME = 7
+  COLUMN_SPEED = 8
+  COLUMN_URL = 9
+  COLUMN_MARKORDER = 10
+
+  ORDER_UNREAD = "0"
+  ORDER_READ = "1"
+  ORDER_NORMAL = "2"
 
   POPUP_OPEN_WITH_WEB_BROWSER = 0
   POPUP_COPY_URL = 1
@@ -54,9 +61,17 @@ class ThreadListView < Qt::Widget
     tool_layout.addWidget(@search_button)
     connect(@search_button, SIGNAL("clicked()"),
             self, SLOT("search()"))
-    connect(@search_line, SIGNAL("returnPressed()"),
+    connect(@search_line, SIGNAL("textChanged(const QString&)"),
             self, SLOT("search()"))
 
+    @filter_button = Qt::ToolButton.new(self)
+    @filter_button.setPixmap(KDE::SmallIcon("filter"))
+    @filter_button.setToggleButton(true)
+    @filter_button.setEnabled(false)
+    tool_layout.addWidget(@filter_button)
+    connect(@filter_button, SIGNAL("toggled(bool)"),
+            self, SLOT("filter(bool)"))
+
     @close_button = Qt::ToolButton.new(self)
     @close_button.setPixmap(KDE::SmallIcon("fileclose"))
     @close_button.setEnabled(false)
@@ -77,6 +92,7 @@ class ThreadListView < Qt::Widget
     @list.addColumn("Thread name")
     @list.addColumn("Res")
     @list.addColumn("Read")
+    @list.addColumn("Unread")
     @list.addColumn("Open time")
     @list.addColumn("Thread speed")
 #    @list.addColumn("Thread url")
@@ -110,7 +126,7 @@ class ThreadListView < Qt::Widget
         dat_file_name = Regexp.last_match(1)
         open_time = Time::at(Regexp.last_match(2).to_i)
         title = Regexp.last_match(3)
-        num = Regexp.last_match(4)
+        num = Regexp.last_match(4).to_i
         speed = num.to_i / ((Time::now - open_time) / 86400.0)
 
         dat_url = Util.make_dat_url(@board_url, dat_file_name)
@@ -123,15 +139,26 @@ class ThreadListView < Qt::Widget
 
     prev_item = nil
     thread_list.each_with_index {|thread, i|
-      item = KDE::ListViewItem.new(@list, prev_item)
+      item = ThreadListViewItem.new(@list, prev_item)
       item.setText(COLUMN_NO, "%4s" % (i+1))
       item.setText(COLUMN_TITLE, thread.title)
       item.setText(COLUMN_RESNUM, "%4s" % thread.res_num)
-      item.setText(COLUMN_READNUM, "%4s" % thread.read_num) if thread.read_num
+      item.setText(COLUMN_READNUM, "%4s" % thread.read_num) if thread.read_num != 0
+      item.setText(COLUMN_UNREADNUM, "%4s" % (thread.res_num - thread.read_num)) if thread.read_num != 0
       item.setText(COLUMN_OPENTIME, thread.open_time.strftime("%y/%m/%d %H:%M"))
       item.setText(COLUMN_SPEED, thread.speed.to_s)
       item.setText(COLUMN_URL, thread.dat_url)
 
+      if thread.res_num > thread.read_num && thread.read_num != 0 then
+        item.setPixmap(COLUMN_MARK, Qt::Pixmap.new("unread.png"))
+        item.setText(COLUMN_MARKORDER, ORDER_UNREAD)
+      elsif thread.res_num == thread.read_num then
+        item.setPixmap(COLUMN_MARK, Qt::Pixmap.new("read.png"))
+        item.setText(COLUMN_MARKORDER, ORDER_READ)
+      else
+        item.setText(COLUMN_MARKORDER, ORDER_NORMAL)
+      end
+
       prev_item = item
     }
 
@@ -155,6 +182,24 @@ class ThreadListView < Qt::Widget
     elsif str != ""
       search_new(str)
       @prev_search_text = str
+      @filter_button.setOn(true)
+      filter(true)
+    else
+      search_clear
+      @filter_button.setOn(false)
+    end
+  end
+
+  def filter(on)
+    it = Qt::ListViewItemIterator.new(@list)
+    while it.current do
+      item = it.current
+      if on && ! item.pixmap(COLUMN_SEARCH) then
+        item.setVisible(false)
+      else
+        item.setVisible(true)
+      end
+      it += 1
     end
   end
 
@@ -166,7 +211,8 @@ class ThreadListView < Qt::Widget
     it = Qt::ListViewItemIterator.new(@list)
     while it.current do
       item = it.current
-      item.setText(COLUMN_SEARCH, "")
+      item.setPixmap(COLUMN_SEARCH, Qt::Pixmap.new)
+      it += 1
     end
   end
 
@@ -178,7 +224,7 @@ class ThreadListView < Qt::Widget
     regexp = Regexp.new(str, Regexp::IGNORECASE)
     while it.current do
       item = it.current
-      item.setText(COLUMN_SEARCH, "") # clear
+      item.setPixmap(COLUMN_SEARCH, Qt::Pixmap.new) # clear
       title = item.text(COLUMN_TITLE)
 
       if title.match(regexp) then
@@ -240,6 +286,21 @@ class ThreadListView < Qt::Widget
 
   def enable_buttons
     @search_button.setEnabled(true)
+    @filter_button.setEnabled(true)
     @close_button.setEnabled(true)
   end
 end
+
+class ThreadListViewItem < KDE::ListViewItem
+  def compare(item, col, ascending)
+    case col
+    when ThreadListView::COLUMN_MARK
+      key1 = key(ThreadListView::COLUMN_MARKORDER, ascending)
+      key2 = item.key(ThreadListView::COLUMN_MARKORDER, ascending)
+
+      key1.to_i <=> key2.to_i
+    else
+      key(col, ascending) <=> item.key(col, ascending)
+    end
+  end
+end
