@@ -44,6 +44,19 @@ module Util
     return TYPE_UNKNOWN
   end
 
+  def self.board_url_to_board_type_name(board_url)
+    case self.board_type(board_url)
+    when TYPE_2CH
+      "2ch"
+    when TYPE_MACHIBBS
+      "machibbs"
+    when TYPE_JBBS
+      "jbbs.livedoor.jp"
+    when TYPE_UNKNOWN
+      "?"
+    end
+  end
+
   def self.board_url?(url)
     url_2ch = %r|http://.*\.2ch\.net/.*|
     url_bbspink = %r|http://.*\.bbspink\.com/.*|
@@ -166,11 +179,15 @@ module Util
     end
   end
 
-  def self.dat_url_to_index_path(dat_url)
+  def self.dat_url_to_dat_path(dat_url)
     dir = self.dat_url_to_dat_dir_path(dat_url)
     dat_file_name = self.dat_url_to_dat_file_name(dat_url)
 
-    dir + "/" + dat_file_name + ".idx"
+    dir + "/" + dat_file_name
+  end
+
+  def self.dat_url_to_index_path(dat_url)
+    self.dat_url_to_dat_path(dat_url) + ".idx"
   end
 
   def self.dat_url_to_dat_dir_path(dat_url)
@@ -197,6 +214,13 @@ module Util
     "http://#{URI.parse(url).host}/#{board_id}/dat/#{thread_id}.dat"
   end
 
+  def self.dat_url_to_offlaw_path(dat_url)
+    thread_id = self.dat_url_to_thread_id(dat_url)
+    board_id = self.dat_url_to_board_id(dat_url)
+    session_id = CGI.escape(Account.instance.session_id)
+    "/test/offlaw.cgi?raw=0.0&bbs=#{board_id}&key=#{thread_id}&sid=#{session_id}"
+  end
+
   def self.make_dat_url(board_url, dat_file_name)
     case self.board_type(board_url)
     when TYPE_2CH, TYPE_MACHIBBS, TYPE_UNKNOWN
